@@ -18,7 +18,16 @@ void Icon::paint(QPainter* painter, const QStyleOptionGraphicsItem *option, QWid
 	if (!inMove)
 		painter->setOpacity(0.8);
 	else 
+	{
+		painter->setOpacity(0.5);
+		painter->setPen(Qt::green);
+		painter->setBrush(Qt::green);
+		painter->drawRect(-x,-y,800,50);
+		painter->setPen(Qt::red);
+		painter->setBrush(Qt::red);
+		painter->drawRect(-x,480-y-50,800,50);
 		painter->setOpacity(0.9);
+	}
 
 	if (active)
 	{
@@ -34,7 +43,6 @@ void Icon::paint(QPainter* painter, const QStyleOptionGraphicsItem *option, QWid
 	{
 		if (type==0)
 			painter->drawPixmap(0,0,game->iconExitPix);
-		
 		else if (type==1)
 			painter->drawPixmap(0,0,game->iconSoundOffPix);
 		else if (type==2)
@@ -71,7 +79,7 @@ void Icon::advance(int step)
 	if (x<0) x=0;
 	if (x>740) x=740;
 	if (y<0) y=0;
-	if (y>420) y=420;
+	if (y>430) y=430;
 
 	if (y>380) //deactivate
 	{
